# config.py

"""Configuration settings for TidyFlow."""

DEFAULT_MISSING_VALUE_STRATEGY = 'mean'
DEFAULT_CATEGORICAL_ENCODING = 'onehot'
DEFAULT_SCALING_METHOD = 'standard'
DEFAULT_FEATURE_ENGINEERING_METHOD = 'poly'
DEFAULT_OUTLIER_HANDLING_METHOD = 'iqr'
DEFAULT_OUTLIER_HANDLING_STRATEGY = 'clip'
